@@ -22,4 +22,6 @@ def create_connection(database: str, user: str, password: str, host: str, port:
         con_string = 'postgresql://'+user+':'+password+'@'+host+':'+port+'/'+database
     if sgbd == 'mysql':
         con_string = 'mysql+pymysql://'+user+':'+password+'@'+host+':'+port+'/'+database
+    if sgbd == 'redshift':
+        con_string = f'redshift+psycopg2://{user}:{password}@{host}:{port}/{db}'
     return create_engine(con_string)
\ No newline at end of file
